@@ -49,10 +49,6 @@ DEFAULT_VALIDATIONS_PATH = \
 # Swift via SwiftPlanStorageBackend to identify them from other containers
 TRIPLEO_META_USAGE_KEY = 'x-container-meta-usage-tripleo'
 
-# OBJECT_META_KEY_PREFIX is used to prefix Swift metadata keys per object
-# in SwiftPlanStorageBackend
-OBJECT_META_KEY_PREFIX = 'x-object-meta-'
-
 #: List of names of parameters that contain passwords
 PASSWORD_PARAMETER_NAMES = (
     'AdminPassword',
@@ -64,9 +60,12 @@ PASSWORD_PARAMETER_NAMES = (
     'CephAdminKey',
     'CephClientKey',
     'CephClusterFSID',
+    'CephMdsKey',
+    'CephManilaClientKey',
     'CephMonKey',
     'CephRgwKey',
     'CinderPassword',
+    'CongressPassword',
     'Ec2ApiPassword',
     'GlancePassword',
     'GnocchiPassword',
@@ -84,6 +83,9 @@ PASSWORD_PARAMETER_NAMES = (
     'NeutronMetadataProxySharedSecret',
     'NeutronPassword',
     'NovaPassword',
+    'OctaviaHeartbeatKey',
+    'OctaviaPassword',
+    'PacemakerRemoteAuthkey',
     'PankoPassword',
     'RabbitPassword',
     'RedisPassword',
@@ -91,6 +93,9 @@ PASSWORD_PARAMETER_NAMES = (
     'SnmpdReadonlyUserPassword',
     'SwiftHashSuffix',
     'SwiftPassword',
+    'TackerPassword',
     'TrovePassword',
     'ZaqarPassword',
 )
+
+PLAN_NAME_PATTERN = '^[a-zA-Z0-9-]+$'
